@@ -90,11 +90,6 @@ mtcars %>%
 mtcars %>%
     take(mean = mean(disp), n = .N, by = list(am, vs))
 
-# parametric evaluation:
-var = quote(mean(cyl))
-take(mtcars, eval(var))
-
-
 # You can group by expressions:
 mtcars %>%
     take(
@@ -102,6 +97,22 @@ mtcars %>%
         by = list(vsam = vs + am)
     )
 
+# parametric evaluation:
+var = quote(mean(cyl))
+mtcars %>% 
+    let(mean_cyl = eval(var)) %>% 
+    head()
+take(mtcars, eval(var))
+
+# all together
+new_var = "mean_cyl"
+mtcars %>% 
+    let((new_var) := eval(var)) %>% 
+    head()
+take(mtcars, (new_var) := eval(var))
+
+
+
 ## ------------------------------------------------------------------------
 # examples from 'dplyr'
 # newly created variables are available immediately
